manifest_checker.ManifestChecker
Run the standard Stagecoach manifest checks for a project.
Usage
manifest_checker.ManifestChecker()Parameters
manifest_file: str | Path-
Path to the manifest file that defines the project directory.
severity_level: Severity-
Minimum severity that should cause passes to return
False.
Attributes
manifest: dict-
Parsed manifest contents.
project_dir: str-
Project working directory declared by the manifest.
severity_level: Severity- Failure threshold used by passes.
Methods
| Name | Description |
|---|---|
| passes() | Determine whether the manifest passes the configured threshold. |
| run_all() | Run all configured project checks. |
passes()
Determine whether the manifest passes the configured threshold.
Usage
passes()Returns
bool-
Truewhen every check result falls belowself.severity_levelandFalseotherwise.
run_all()
Run all configured project checks.
Usage
run_all()Returns
list[CheckResult]- Results from each Stagecoach project validation check.